@@ -24,7 +24,6 @@ IFCFG_DIR=/etc/sysconfig/network-scripts
 IFCFG=${IFCFG_DIR}/ifcfg-${VENET_DEV}
 NETFILE=/etc/sysconfig/network
 HOSTFILE=/etc/hosts
-ROUTE=${IFCFG_DIR}/route-${VENET_DEV}
 NETWORKRESTART=
 
 function fix_ifup()
@@ -54,16 +53,12 @@ IPADDR=127.0.0.1
 NETMASK=255.255.255.255
 BROADCAST=0.0.0.0" > $IFCFG || error "Can't write to file $IFCFG" $VZ_FS_NO_DISK_SPACE
 
-
-	remove_fake_old_route ${ROUTE}
-	if ! grep -q "${FAKEGATEWAYNET}/24 dev ${VENET_DEV}" ${ROUTE} 2>/dev/null; then
-		echo "${FAKEGATEWAYNET}/24 dev ${VENET_DEV} scope host
-default via ${FAKEGATEWAY}" >> ${ROUTE} || error "Can't create ${ROUTE}" ${VZ_FS_NO_DISK_SPACE}
-	fi
 	# Set /etc/sysconfig/network
 	put_param $NETFILE NETWORKING yes
-	put_param $NETFILE GATEWAY ${FAKEGATEWAY}
-
+	# Set default route to venet0
+	put_param $NETFILE GATEWAYDEV ${VENET_DEV}
+	# Remove old (obsoleted) fake route
+	del_param $NETFILE GATEWAY
 	# setup ipv6
 	setup6_network
 
@@ -92,12 +87,13 @@ function create_config()
 {
 	local ip=$1
 	local ifnum=$2
+	local file=${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum}
 
 	echo "DEVICE=${VENET_DEV}:${ifnum}
 ONBOOT=yes
 IPADDR=${ip}
-NETMASK=255.255.255.255" > ${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum} ||
-	error "Unable to create interface config file" ${VZ_FS_NO_DISK_SPACE}
+NETMASK=255.255.255.255" > $file ||
+	error "Can't write to file $file" ${VZ_FS_NO_DISK_SPACE}
 }
 
 function add_ip6()
@@ -152,7 +148,7 @@ function backup_configs()
 	cd ${IFCFG_DIR} || return 1
 	if ls ${VENET_DEV_CFG}:* > /dev/null 2>&1; then
 		${CP} ${VENET_DEV_CFG}:* ${IFCFG_DIR}/bak/ ||
-			error "Unable to backup intrface config files" ${VZ_FS_NO_DISK_SPACE}
+			error "Unable to backup interface config files" ${VZ_FS_NO_DISK_SPACE}
 	fi
 }
 
